@@ -665,7 +665,7 @@ class Tool:
         :return:
         """
 
-        def analysis_dict(self, item, type="install"):
+        def analysis_dict(item, type="install"):
             if type == "install":
                 key = item.keys()
                 value = item.values()
